@@ -74,11 +74,12 @@ class Debugger(Pdb):
     - overrides list command to search for current block instead
       of using 5 lines of context
     """
-    def __init__(self, tcbk):
+    def __init__(self, tcbk=None):
         Pdb.__init__(self)
         self.reset()
-        while tcbk.tb_next is not None:
-            tcbk = tcbk.tb_next
+        if tcbk:
+            while tcbk.tb_next is not None:
+                tcbk = tcbk.tb_next
         self._tcbk = tcbk
         self._histfile = osp.join(os.environ["HOME"], ".pdbhist")
 
@@ -153,7 +154,7 @@ class Debugger(Pdb):
                 ret = ret + self.get_class_members(base)
         return ret
 
-    ## specific / overidden commands
+    ## specific / overridden commands
     def do_list(self, arg):
         """overrides default list command to display the surrounding block
         instead of 5 lines of context
@@ -187,3 +188,5 @@ def pm():
     dbg = Debugger(sys.last_traceback)
     dbg.start()
 
+def set_trace():
+    Debugger().set_trace(sys._getframe().f_back)
