@@ -9,8 +9,7 @@ __docformat__ = "restructuredtext en"
 import sys
 from warnings import warn
 
-
-class deprecated(type):
+class class_deprecated(type):
     """metaclass to print a warning on instantiation of a deprecated class"""
 
     def __call__(cls, *args, **kwargs):
@@ -36,7 +35,7 @@ def class_renamed(old_name, new_class, message=None):
     clsdict['__deprecation_warning__'] = message
     try:
         # new-style class
-        return deprecated(old_name, (new_class,), clsdict)
+        return class_deprecated(old_name, (new_class,), clsdict)
     except (NameError, TypeError):
         # old-style class
         class DeprecatedClass(new_class):
@@ -59,26 +58,23 @@ def class_moved(new_class, old_name=None, message=None):
             old_name, new_class.__module__, new_class.__name__)
     return class_renamed(old_name, new_class, message)
 
-
-def deprecated_function(new_func, message=None):
-    """Creates a function which fires a DeprecationWarning when used.
-
-    For example, if <bar> is deprecated in favour of <foo>:
-
-    >>> bar = deprecated_function(foo, 'bar is deprecated')
-    >>> bar()
-    sample.py:57: DeprecationWarning: bar is deprecated
-      bar()
-    >>>
+def deprecated(reason=None):
+    """Decorator that raises a DeprecationWarning to print a message
+    when the decorated function is called.
     """
-    if message is None:
-        message = "this function is deprecated, use %s instead" % (
-            new_func.func_name)
-    def deprecated(*args, **kwargs):
-        warn(message, DeprecationWarning, stacklevel=2)
-        return new_func(*args, **kwargs)
-    return deprecated
+    def deprecated_decorator(func):
+        message = reason or 'this function is deprecated, use %s instead'
+        if '%s' in message:
+            message = message % func.func_name
+        def wrapped(*args, **kwargs):
+            warn(message, DeprecationWarning, stacklevel=2)
+            return func(*args, **kwargs)
+        return wrapped
+    return deprecated_decorator
 
+@deprecated('replace deprecated_function(f,m) with deprecated(m)(f)')
+def deprecated_function(func, message=None):
+    return deprecated(message)(func)
 
 def moved(modpath, objname):
     """use to tell that a callable has been moved to a new module.
@@ -99,36 +95,5 @@ def moved(modpath, objname):
         return getattr(m, objname)(*args, **kwargs)
     return callnew
 
-# from logilab.common.modutils import LazyObject
-
-# class WarnLazyObject(LazyObject):
-#     def __init__(self, oldname, newname):
-#         # XXX doesn't work if module isn't in a package
-#         package, module = newname.rsplit('.', 1)
-#         super(WarnLazyObject, self).__init__(package, module)
-#         self.oldname = oldname
-#         self.newname = newname
-#         print 'hop', oldname, newname
-#         sys.modules[oldname] = self
-
-#     def __getobj(self):
-#         if self._imported is None:
-#             message = "module %s has moved, it's now %s" % (
-#                 self.oldname, self.newname)
-#             warn(message, DeprecationWarning, stacklevel=2)
-#         return super(WarnLazyObject, self).__getobj()
-
-
-# module_moved = WarnLazyObject
-
-def obsolete(reason="This function is obsolete"):
-    """this function is an alternative to `deprecated_function`
-    when there's no real replacement for the deprecated function
-    """
-    def newdecorator(func):
-        def wrapped(*args, **kwargs):
-            warn(reason, DeprecationWarning, stacklevel=2)
-            return func(*args, **kwargs)
-        return wrapped
-    return newdecorator
+obsolete = deprecated('obsolete is deprecated, use deprecated instead')(deprecated)
 
