@@ -113,7 +113,7 @@ def run_tests(tests, quiet, verbose, runner=None, capture=0):
             print "Executing", test
         result = run_test(test, verbose, runner, capture)
         if type(result) is type(''):
-            # an unexpected error occured
+            # an unexpected error occurred
             skipped.append( (test, result))
         else:
             if all_result is None:
@@ -466,8 +466,13 @@ class SkipAwareTextTestRunner(unittest.TextTestRunner):
         if self.options is not None:
             tags_pattern = getattr(self.options, 'tags_pattern', None)
             if tags_pattern is not None:
-                tags = getattr(test, 'tags', Tags())
-                return tags.match(tags_pattern)
+                tags = getattr(test, 'tags', None)
+                if tags is not None:
+                    return tags.match(tags_pattern)
+                if isinstance(test, types.MethodType):
+                    tags = getattr(test.im_class, 'tags', Tags())
+                    return tags.match(tags_pattern)
+                return False
         return True # no pattern
 
     def _makeResult(self):
@@ -769,7 +774,7 @@ Examples:
                                                   options=self.options)
 
         def removeSucceededTests(obj, succTests):
-            """ Recurcive function that removes succTests from
+            """ Recursive function that removes succTests from
             a TestSuite or TestCase
             """
             if isinstance(obj, TestSuite):
@@ -905,7 +910,7 @@ def capture_stderr(printonly=None):
 def unittest_main(module='__main__', defaultTest=None,
                   batchmode=False, cvg=None, options=None,
                   outstream=sys.stderr):
-    """use this functon if you want to have the same functionality
+    """use this function if you want to have the same functionality
     as unittest.main"""
     return SkipAwareTestProgram(module, defaultTest, batchmode,
                                 cvg, options, outstream)
@@ -1339,7 +1344,7 @@ succeeded test into", osp.join(os.getcwd(),FILE_RESTART)
                 self.fail( "tuple %s has no attributes (%s expected)"%(tup,
                     dict(element.attrib)))
             self.assertDictEquals(element.attrib, tup[1])
-        # check childrend
+        # check children
         if len(element) or len(tup)>2:
             if len(tup)<=2:
                 self.fail( "tuple %s has no children (%i expected)"%(tup,
@@ -1398,7 +1403,7 @@ succeeded test into", osp.join(os.getcwd(),FILE_RESTART)
         # make sure we compare from the beginning of the stream
         stream1.seek(0)
         stream2.seek(0)
-        # ocmpare
+        # compare
         self._difftext(stream1.readlines(), stream2.readlines(), junk,
              msg_prefix)
 
@@ -1768,7 +1773,7 @@ class Tags(set):
         return eval(exp, {}, self)
 
 def require_version(version):
-    """ Compare version of python interpretor to the given one. Skip the test
+    """ Compare version of python interpreter to the given one. Skip the test
     if older.
     """
     def check_require_version(f):
